@@ -15,9 +15,9 @@ $perl -i -lne 'print unless /(?:\.tar\.gz$|^dist)/' MANIFEST && \
 make clean && \
 $perl Makefile.PL && \
 make && \
-make test && \
+TEST_AUTHOR=1 NET_TEST=1 make test && \
 make disttest && \
 make dist && \
 cp -f *.tar.gz dist/ && \
-make distclean && \
+make clean && \
 echo "All is OK"
